@@ -33,8 +33,7 @@ class QCTests:
 
     """
     def __init__(self, obj, **kwargs):
-
-        print('test')
+        self._obj = obj
 
     def add_missing_value_test(self, var_name, missing_value=None,
                                missing_value_att_name='missing_value',
