@@ -27,4 +27,6 @@ from .sample_files import (EXAMPLE_SONDE1, EXAMPLE_LCL1, EXAMPLE_MET_CSV,
                            EXAMPLE_EBBR2, EXAMPLE_BRS, EXAMPLE_AERI,
                            EXAMPLE_MFRSR, EXAMPLE_SURFSPECALB1MLAWER,
                            EXAMPLE_SIGMA_MPLV5, EXAMPLE_RL1,
-                           EXAMPLE_CO2FLX4M, EXAMPLE_SIRS, EXAMPLE_IRTSST)
+                           EXAMPLE_CO2FLX4M, EXAMPLE_SIRS, EXAMPLE_IRTSST,
+                           EXAMPLE_MET_TEST1, EXAMPLE_MET_TEST2,
+                           EXAMPLE_STAMP_WILDCARD)
